Stan Math Library: doxygen/boost.dox File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces
doxygen/boost.dox File Reference

## Namespaces
| boost
| Reimplementing boost functionality.
| boost::math
| Reimplmeneting boost functionality for `stan::math::var` and and bugs in classification of integer types.

[ Stan Home Page ] © 2011–2016, Stan Development Team.